# Game: SHIPWRECKS

No game-specific readme content prepared

## Field Day Open Game Data

Retrieved from https://fielddaylab.wisc.edu/opengamedata
These anonymous data are provided in service of future educational data mining research.
They are made available under the Creative Commons CCO 1.0 Universal license.
See https://creativecommons.org/publicdomain/zero/1.0/

### Suggested citation

#### Field Day. (2019). Open Educational Game Play Logs - [dataset ID]. Retrieved [today's date] from https://opengamedata.fielddaylab.wisc.edu/

## Database Columns

The individual columns recorded in the database for this game.

**session_id** : *str* - session_id, Unique identifier for the gameplay session  
**app_id** : *str* - app_id, A string identifying which game from which the event came  
**timestamp** : *datetime* - timestamp, The time when the event was logged  
**event_name** : *str* - event_name, The type of event logged  
**event_data** : *json* - event_data, Data specific to an event type, encoded as a JSON string  
**event_source** : *enum('GAME', 'GENERATED')* - event_source, An enum member indicating whether the event was generated by the Game, or by a Detector  
**app_version** : *str* - app_version, The version of the game from which the event came  
**app_branch** : *str* - app_branch, The branch of the game from which the event came  
**log_version** : *str* - log_version, The version of the logging code for the game from which the event came  
**offset** : *timedelta* - offset, The local offset of the event time from GMT  
**user_id** : *str* - user_id, A custom, per-player ID, only exists if player entered an ID on one of our custom portal pages, else null  
**user_data** : *json* - user_data, Metadata specific to a user, encoded as a JSON string  
**game_state** : *json* - game_state, Metadata about the state of the game when the event occurred, encoded as a JSON string  
**index** : *int* - index, Counter of events in the session, from 0. A row with session_n = i is the (i+1)-th event of the session  

## Event Object Elements

The elements (member variables) of each Event object, available to programmers when writing feature extractors. The right-hand side shows which database column(s) are mapped to a given element.

**session_id** = Column '*session_id*' (index 0)  
**app_id** = Column '*app_id*' (index 1)  
**timestamp** = Column '*timestamp*' (index 2)  
**event_name** = Column '*event_name*' (index 3)  
**event_data** = Column '*event_data*' (index 4)  
**event_source** = Column '*event_source*' (index 5)  
**app_version** = Column '*app_version*' (index 6)  
**app_branch** = Column '*app_branch*' (index 7)  
**log_version** = Column '*log_version*' (index 8)  
**time_offset** = Column '*offset*' (index 9)  
**user_id** = Column '*user_id*' (index 10)  
**user_data** = Column '*user_data*' (index 11)  
**game_state** = Column '*game_state*' (index 12)  
**event_sequence_index** = Column '*index*' (index 13)  



## Logged Events  

The individual fields encoded in the *game_state* and *user_data* Event element for all event types, and the fields in the *event_data* Event element for each individual event type logged by the game.  

### Enums  

| **Name** | **Values** |
| ---      | ---        |  

### Game State  

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |  

### User Data  

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |  

### **start_mission**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |  

### **checkpoint**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |
| status | N/A | Checkpoint status | |  

### **open_map**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |  

### **scanning**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |  

### **scan_complete**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |  

### **dive_begin**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |  

### **new_evidence**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |
| type | N/A | Type of evidence found | |
| source | N/A | Source where the evidence was gathered from | |
| key | N/A | Name/ID for the evidence found | |  

### **mission_complete**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |  

### **update_ship_overview**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |
| field | N/A | Field in ship overview that was updated | |
| evidence | N/A | Evidence placed in ship overview | |  

### **view_desk**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |  

### **view_tab**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |
| tab_name | N/A | Name of tab opened | |  

### **view_chat**

N/A

#### Event Data

| **Name** | **Type** | **Description** | **Sub-Elements** |
| ---      | ---      | ---             | ---         |
| mission_id | N/A | ID for the current mission | |
| name | N/A | Name of NPC in the chat | |  

## Detected Events  

The custom, data-driven Events calculated from this game's logged events by OpenGameData when an 'export' is run.  

None  

## Processed Features  

The features/metrics calculated from this game's event logs by OpenGameData when an 'export' is run.  

**ActiveJobs** : **, *Aggregate feature*   
Count of players who left off on each mission.  
  

**EventList** : **, *Aggregate feature*   
List of all events in a session  
  

**JobsCompleted** : **, *Aggregate feature*   
List of missions completed in a session  
  

**PlayerSummary** : **, *Aggregate feature*   
Summary of player statistics (active session time, jobs completed, number of sessions)  
  

**PopulationSummary** : **, *Aggregate feature*   
Summary of population statistics (active session time, average jobs completed count, average session count)  
  

**EvidenceBoardCompleteCount** : **, *Aggregate feature*  (disabled)  
Evidence board completes in a session  
  

**SessionDuration** : **, *Aggregate feature*   
Time spent playing in a given session  
  

**SessionID** : **, *Aggregate feature*   
The player's session ID number for this play session  
  

**TopJobCompletionDestinations** : **, *Aggregate feature*   
Top accepted missions after previously completing a given mission  
  

**TopJobSwitchDestinations** : **, *Aggregate feature*   
Top accepted missions after leaving a given mission  
  

**TotalDiveTime** : **, *Aggregate feature*  (disabled)  
Total time spent diving in a session  
  

**MissionDiveTime** : **, *Per-count feature*  (disabled)  
Time spent diving for a given mission  
  

**MissionSonarTimeToComplete** : **, *Per-count feature*  (disabled)  
Time taken to complete sonar scan for a given mission  
  

**JobsAttempted** : **, *Per-count feature*   
Subfeatures for number of mission starts and completes, percent complete, and avg/std time to complete  
*Sub-features*:  

- **job-name** : *string*, String name for a mission  

- **num-starts** : *int*, Number of mission_start events for a given mission  

- **num-completes** : *int*, Number of mission_complete events for a given mission  

- **percent-complete** : *float*, Percent of mission which were accepted and completed  

- **avg-time-complete** : *float*, Average time taken from accepting to completing a mission  

- **std-dev-complete** : *float*, Standard deviation of time taken to complete  
  

## Other Elements  

Other (potentially non-standard) elements specified in the game's schema, which may be referenced by event/feature processors.  

db_columns : {'event_date': 'The date on which the event was logged', 'event_timestamp': 'The time (in microseconds, UTC) at which the event was logged on the client', 'event_name': 'The name of the event', 'event_params': 'A repeated record of the parameters associated with this event', 'event_previous_timestamp': 'The time (in microseconds, UTC) at which the event was previously logged on the client', 'event_value_in_usd': "The currency-converted value (in USD) of the event's value parameter", 'event_bundle_sequence_id': 'The sequential ID of the bundle in which these events were uploaded', 'event_server_timestamp_offset': 'Timestamp offset between collection time and upload time in micros', 'user_id': 'The user ID set via the setUserId API', 'user_pseudo_id': 'The pseudonymous id (e.g., app instance ID) for the user', 'user_properties': 'A repeated record of user properties set with the setUserProperty API', 'user_first_touch_timestamp': 'The time (in microseconds) at which the user first opened the app or visited the site', 'user_ltv': 'A record of Lifetime Value information about the user', 'device': 'A record of device information', 'geo': "A record of the user's geographic information", 'app_info': 'A record of information on the app', 'traffic_source': 'Name of the traffic source that first acquired the user', 'stream_id': 'The numeric ID of the stream', 'platform': 'The platform on which the app was built', 'event_dimensions': 'Dimensions associated with the event', 'ecommerce': 'A record of information about ecommerce', 'items': 'A repeated record of items included in this event'}  

mission_map : {'Level1': 0, 'Level2': 1, 'Level3': 2, 'Level4': 3}  

### Other Ranges  

Extra ranges specified in the game's schema, which may be referenced by event/feature processors.  

level_range : range(0, 3)

No changelog prepared

